import { IStringIndexed } from "../types";
export interface ITokenAnswer {
    access_token: string;
    refresh_token: string;
}
export interface IOauth2Config {
    clientID: string;
    clientSecret: string;
    redirectURI: string;
    tokenURL: string;
    authorizeURL: string;
}
export declare class RefreshTokenExpiredError extends Error {
    constructor();
}
export default class Oauth2 {
    private readonly config;
    private readonly basicAuthHeaders;
    private lastToken?;
    private fetchingToken?;
    constructor(config: IOauth2Config, lastToken?: ITokenAnswer);
    private postTokenRequest;
    /**
     * @throws RefreshTokenExpiredError if no refreshToken has expired and no `code` param is given
     */
    requestToken(code?: string): Promise<ITokenAnswer>;
    requestAuth(state: string, query?: IStringIndexed): Promise<Response>;
    getRequestAuthURL(state: string, query?: IStringIndexed): string;
    private refreshToken;
    private getTokenAuthHeaders;
    private mergeHeaders;
    authenticatedGet(url: string, customHeaders?: IStringIndexed): Promise<Response>;
    authenticatedPost(url: string, body: {}, form?: boolean, customHeaders?: IStringIndexed): Promise<Response>;
}
